@@ -51,18 +51,11 @@ Authors
 - Fernando Perez: refactoring, documentation, cleanups.
 - VáclavŠmilauer <eudoxos-AT-arcig.cz>: Prompt generatlizations.
 """
-from __future__ import print_function
-
 #-----------------------------------------------------------------------------
 # Imports
 #-----------------------------------------------------------------------------
 
 # Stdlib
-from future import standard_library
-standard_library.install_aliases()
-
-from builtins import range
-from builtins import object
 import io
 import imp
 import os
