@@ -119,18 +119,12 @@ Authors
 - VáclavŠmilauer <eudoxos-AT-arcig.cz>: Prompt generalizations.
 - Skipper Seabold, refactoring, cleanups, pure python addition
 """
-from __future__ import print_function
 
 #-----------------------------------------------------------------------------
 # Imports
 #-----------------------------------------------------------------------------
 
 # Stdlib
-from future import standard_library
-standard_library.install_aliases()
-
-from builtins import range
-from builtins import object
 import atexit
 import os
 import re
