@@ -7,7 +7,8 @@
 #
 # plotting should be set up as usual
 
-from past.builtins import execfile
+from yade.yexecfile import execfile
+
 import matplotlib
 matplotlib.use('Agg')  # headless backend, makes rendering plots after the simulation _much_ faster (and more reliable)
 
