@@ -13,15 +13,6 @@
 #include <preprocessing/dem/Shop.hpp>
 #include <preprocessing/dem/SpherePack.hpp>
 
-// https://codeyarns.com/2014/03/11/how-to-selectively-ignore-a-gcc-warning/
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wpragmas"
-#pragma GCC diagnostic ignored "-Wunused-function"
-// Code that generates this warning, Note: we cannot do this trick in yade. If we have a warning in yade, we have to fix it! See also https://gitlab.com/yade-dev/trunk/merge_requests/73
-// This method will work once g++ bug https://gcc.gnu.org/bugzilla/show_bug.cgi?id=53431#c34 is fixed.
-#include <lib/pyutil/numpy_boost.hpp>
-#pragma GCC diagnostic pop
-
 #ifdef YADE_OPENGL
 #include <lib/opengl/GLUtils.hpp>
 #include <lib/opengl/OpenGLWrapper.hpp>
@@ -39,21 +30,20 @@ YADE_PLUGIN((TesselationWrapper));
 CREATE_LOGGER(TesselationWrapper);
 
 // helper macro do assign Matrix3r values to subarrays
-#define MATRIX3R_TO_NUMPY(mat, arr)                                                                                                                            \
-	arr[0] = mat(0, 0);                                                                                                                                    \
-	arr[1] = mat(0, 1);                                                                                                                                    \
-	arr[2] = mat(0, 2);                                                                                                                                    \
-	arr[3] = mat(1, 0);                                                                                                                                    \
-	arr[4] = mat(1, 1);                                                                                                                                    \
-	arr[5] = mat(1, 2);                                                                                                                                    \
-	arr[6] = mat(2, 0);                                                                                                                                    \
-	arr[7] = mat(2, 1);                                                                                                                                    \
-	arr[8] = mat(2, 2);
+#define TENSOR_TO_MATRIX3R(mat, arr)  {                                                                                                                       \
+	arr(0,0) = mat(1, 1);                                                                                                                                    \
+	arr(0,1) = mat(1, 2);                                                                                                                                    \
+	arr(0,2) = mat(1, 3);                                                                                                                                    \
+	arr(1,0) = mat(2, 1);                                                                                                                                    \
+	arr(1,1) = mat(2, 2);                                                                                                                                    \
+	arr(1,2) = mat(2, 3);                                                                                                                                    \
+	arr(2,0) = mat(3, 1);                                                                                                                                    \
+	arr(2,1) = mat(3, 2);                                                                                                                                    \
+	arr(2,2) = mat(3, 3);}
 
 //spatial sort traits to use with a pair of CGAL::sphere pointers and integer.
 //template<class _Triangulation>
 struct RTraits_for_spatial_sort : public CGT::SimpleTriangulationTypes::RTriangulation::Geom_traits {
-	//typedef typename _Triangulation::Geom_traits Gt;
 	typedef CGT::SimpleTriangulationTypes::RTriangulation::Geom_traits Gt;
 	typedef std::pair<const CGT::Sphere*, Body::id_t>                  Point_3;
 
@@ -97,7 +87,7 @@ void build_triangulation_with_ids(const shared_ptr<BodyContainer>& bodies, Tesse
 	int                Sph_Index = sph->getClassIndexStatic();
 	Scene*             scene     = Omega::instance().getScene().get();
 	for (const auto& bi : *bodies) {
-		if (bi->shape->getClassIndex() == Sph_Index) {
+		if (bi and bi->shape->getClassIndex() == Sph_Index and bi->maskOk(TW.groupMask) ) {
 			const Sphere* s = YADE_CAST<Sphere*>(bi->shape.get());
 			//FIXME: is the scene periodicity verification useful in the next line ? Tesselation seems to work in both periodic and non-periodic conditions with "scene->cell->wrapShearedPt(bi->state->pos)". I keep the verification to be consistent with all other uses of "wrapShearedPt" function.
 			const Vector3r& pos = scene->isPeriodic ? scene->cell->wrapShearedPt(bi->state->pos) : bi->state->pos;
@@ -117,7 +107,9 @@ void build_triangulation_with_ids(const shared_ptr<BodyContainer>& bodies, Tesse
 	TW.rad_divided = true;
 	spheres.resize(Ng);
 	pointsPtrs.resize(Ng);
-	std::random_shuffle(pointsPtrs.begin(), pointsPtrs.end());
+	// random shuffling here is suggested in CGAL examples but it is probably not very helpful in yade since the positions are _usually_ random already.
+	// We skip it to avoid unnecessary indeterminacy
+	// std::random_shuffle(pointsPtrs.begin(), pointsPtrs.end());
 	spatial_sort(pointsPtrs.begin(), pointsPtrs.end(), RTraits_for_spatial_sort() /*, CGT::RTriangulation::Weighted_point*/);
 
 	RTriangulation::Cell_handle hint;
@@ -139,15 +131,11 @@ void build_triangulation_with_ids(const shared_ptr<BodyContainer>& bodies, Tesse
 			++TW.n_spheres;
 		}
 	}
-	//cerr << " loaded : " << Ng<<", triangulated : "<<TW.n_spheres<<", mean radius = " << TW.mean_radius<<endl;
 }
 
 Real thickness = 0;
 
-TesselationWrapper::~TesselationWrapper()
-{
-	if (Tes) delete Tes;
-}
+TesselationWrapper::~TesselationWrapper() {}
 
 void TesselationWrapper::clear(void)
 {
@@ -159,34 +147,14 @@ void TesselationWrapper::clear(void)
 	rad_divided = false;
 	bounded     = false;
 	Tes->vertexHandles.clear();
-	facet_it = Tes->Triangulation().finite_edges_end();
-}
-
-void TesselationWrapper::clear2(void) //for testing purpose
-{
-	Tes->Clear();
-
-	//   Pmin = Point(inf, inf, inf);
-	//  Pmax = Point(-inf, -inf, -inf);
-	//  mean_radius = 0;
-	//  n_spheres = 0;
-	//  rad_divided = false;
-	// bounded = false;
-	//  facet_it = Tes->Triangulation().finite_edges_end ();
 }
 
 void TesselationWrapper::insertSceneSpheres(bool reset)
 {
-	// declaration of ‘scene’ shadows a member of ‘yade::TesselationWrapper’ [-Werror=shadow]
-	// 	Scene* scene2 = Omega::instance().getScene().get();
-	// 	Real_timer clock;
-	//         clock.start();
-	// 	const shared_ptr<BodyContainer>& bodies = scene2->bodies;
 	build_triangulation_with_ids(scene->bodies, *this, reset);
-	// 	clock.top("Triangulation");
 }
 
-Real TesselationWrapper::Volume(unsigned int id) { return ((unsigned int)Tes->Max_id() >= id) ? Tes->Volume(id) : -1; }
+Real TesselationWrapper::Volume(unsigned int id) { return ((unsigned int)Tes->Max_id() >= id and Tes->vertex(id)!=NULL ) ? Tes->Volume(id) : 0; }
 
 bool TesselationWrapper::insert(Real x, Real y, Real z, Real rad, unsigned int id)
 {
@@ -216,6 +184,7 @@ bool TesselationWrapper::move(Real x, Real y, Real z, Real rad, unsigned int id)
 void TesselationWrapper::computeTesselation(void)
 {
 	if (not(Tes->vertexHandles.size() > 0)) insertSceneSpheres();
+	addBoundingPlanes();
 	if (!rad_divided) {
 		mean_radius /= n_spheres;
 		rad_divided = true;
@@ -232,32 +201,9 @@ void TesselationWrapper::computeTesselation(Real pminx, Real pmaxx, Real pminy,
 
 void TesselationWrapper::computeVolumes(void)
 {
-	if (not(Tes->vertexHandles.size() > 0)) insertSceneSpheres();
-	if (!bounded) addBoundingPlanes();
 	computeTesselation();
 	Tes->computeVolumes();
 }
-unsigned int TesselationWrapper::NumberOfFacets(bool initIters)
-{
-	if (initIters) InitIter();
-	return Tes->Triangulation().number_of_finite_edges();
-}
-
-void TesselationWrapper::InitIter(void)
-{
-	facet_begin = Tes->Triangulation().finite_edges_begin();
-	facet_end   = Tes->Triangulation().finite_edges_end();
-	facet_it    = facet_begin;
-}
-
-bool TesselationWrapper::nextFacet(std::pair<unsigned int, unsigned int>& facet)
-{
-	if (facet_end == facet_it) return false;
-	facet.first  = facet_it->first->vertex(facet_it->second)->info().id();
-	facet.second = facet_it->first->vertex((facet_it)->third)->info().id();
-	++facet_it;
-	return true;
-}
 
 int TesselationWrapper::addBoundingPlane(short axis, bool positive)
 {
@@ -301,7 +247,7 @@ void TesselationWrapper::addBoundingPlanes(Real pminx, Real pmaxx, Real pminy, R
 		for (int k = 0; k < 6; k++) {
 			while (Tes->vertexHandles[i] != NULL)
 				++i;
-			freeIds[k] = i;
+			freeIds[k] = i++;
 		}
 		// now insert
 		Tes->vertexHandles[freeIds[0]] = Tes->insert(
@@ -323,23 +269,23 @@ void TesselationWrapper::addBoundingPlanes(Real pminx, Real pmaxx, Real pminy, R
 
 void TesselationWrapper::addBoundingPlanes(void) { addBoundingPlanes(Pmin.x(), Pmax.x(), Pmin.y(), Pmax.y(), Pmin.z(), Pmax.z()); }
 
-void TesselationWrapper::setState(bool state) { mma.setState(state ? 2 : 1); }
+void TesselationWrapper::setState(bool state) { mma->setState(state ? 2 : 1, false, false, groupMask); }
 
 void TesselationWrapper::loadState(string filename, bool stateNumber, bool bz2)
 {
-	CGT::TriaxialState& TS = stateNumber ? *(mma.analyser->TS1) : *(mma.analyser->TS0);
+	CGT::TriaxialState& TS = stateNumber ? *(mma->analyser->TS1) : *(mma->analyser->TS0);
 	TS.from_file(filename.c_str(), bz2);
 }
 
 void TesselationWrapper::saveState(string filename, bool stateNumber, bool bz2)
 {
-	CGT::TriaxialState& TS = stateNumber ? *(mma.analyser->TS1) : *(mma.analyser->TS0);
+	CGT::TriaxialState& TS = stateNumber ? *(mma->analyser->TS1) : *(mma->analyser->TS0);
 	TS.to_file(filename.c_str(), bz2);
 }
 
 void TesselationWrapper::defToVtkFromStates(string inputFile1, string inputFile2, string outputFile, bool bz2)
 {
-	mma.analyser->DefToFile(inputFile1.c_str(), inputFile2.c_str(), outputFile.c_str(), bz2);
+	mma->analyser->DefToFile(inputFile1.c_str(), inputFile2.c_str(), outputFile.c_str(), bz2);
 }
 
 void createSphere(shared_ptr<Body>& body, Vector3r position, Real radius, bool /*big*/, bool /*dynamic*/)
@@ -368,7 +314,7 @@ void TesselationWrapper::defToVtkFromPositions(string inputFile1, string inputFi
 		createSphere(body, sp.c, sp.r, false, true);
 		scene->bodies->insert(body);
 	}
-	mma.setState(1);
+	mma->setState(1);
 	scene->bodies->clear();
 	for (size_t i = 0; i < imax; i++) {
 		const SpherePack::Sph& sp(sp2.pack[i]);
@@ -376,49 +322,45 @@ void TesselationWrapper::defToVtkFromPositions(string inputFile1, string inputFi
 		createSphere(body, sp.c, sp.r, false, true);
 		scene->bodies->insert(body);
 	}
-	mma.setState(2);
-	mma.analyser->DefToFile(outputFile.c_str());
+	mma->setState(2);
+	mma->analyser->DefToFile(outputFile.c_str());
 }
 
-void TesselationWrapper::defToVtk(string outputFile) { mma.analyser->DefToFile(outputFile.c_str()); }
+void TesselationWrapper::defToVtk(string outputFile) { mma->analyser->DefToFile(outputFile.c_str()); }
 
 boost::python::dict TesselationWrapper::calcVolPoroDef(bool deformation)
 {
-	delete Tes;
 	CGT::TriaxialState* ts;
-	if (deformation) { //use the final state to compute volumes
-		/*const vector<CGT::Tenseur3>& def =*/mma.analyser->computeParticlesDeformation();
-		Tes = &mma.analyser->TS1->tesselation();
-		ts  = mma.analyser->TS1;
-	} else {
-		Tes = &mma.analyser->TS0->tesselation(); //no reason to use the final state if we don't want to compute deformations, keep using the initial
-		ts  = mma.analyser->TS0;
-	}
+	bounded = true; // TriaxialState already has bounding planes together with the actual spheres, no need to bound again.
+	if (deformation) mma->analyser->computeParticlesDeformation();
+	Tes = &mma->analyser->TS0->tesselation(); //no reason to use the final state if we don't want to compute deformations, keep using the initial
+	ts  = mma->analyser->TS0;
+	computeVolumes();
 	RTriangulation& Tri = Tes->Triangulation();
 	Pmin                = ts->box.base;
 	Pmax                = ts->box.sommet;
-	//if (!scene->isPeriodic) addBoundingPlanes();
-	computeVolumes();
+
 	int bodiesDim = Tes->Max_id() + 1; //=scene->bodies->size();
-	cerr << "bodiesDim=" << bodiesDim << endl;
-	int dim1[] = { bodiesDim };
-	int dim2[] = { bodiesDim, 9 };
-	/// This is the code that needs numpy include
-	//numpy_boost<Body::id_t,1> id(dim1);
-	numpy_boost<Real, 1> vol(dim1);
-	numpy_boost<Real, 1> poro(dim1);
-	numpy_boost<Real, 2> def(dim2);
-	//for(const auto & b :  *scene->bodies){
+	vector<Real> vol_(bodiesDim,0);
+	vector<Real> poro_(bodiesDim,0);
+	vector<Matrix3r> def_(bodiesDim,Matrix3r::Zero()); 
+	
+	boost::python::list vol;
+	boost::python::list poro;
+	boost::python::list def;
+	
 	for (RTriangulation::Finite_vertices_iterator V_it = Tri.finite_vertices_begin(); V_it != Tri.finite_vertices_end(); V_it++) {
-		//id[]=V_it->info().id()
-		//if(!b) continue;
 		const Body::id_t id        = V_it->info().id();
+		if (id<0 or  V_it->info().v()==0 or V_it->info().isFictious) continue;
 		Real             sphereVol = 4.188790 * math::pow((V_it->point().weight()), 1.5); // 4/3*PI*R³ = 4.188...*R³
-		vol[id]                    = V_it->info().v();
-		poro[id]                   = (V_it->info().v() - sphereVol) / V_it->info().v();
-		if (deformation) MATRIX3R_TO_NUMPY(mma.analyser->ParticleDeformation[id], def[id]);
-		//cerr << V_it->info().v()<<" "<<ParticleDeformation[id]<<endl;
+		vol_[id]                    = V_it->info().v();
+		poro_[id]                   = (V_it->info().v() - sphereVol) / V_it->info().v();
+		if (deformation) TENSOR_TO_MATRIX3R(mma->analyser->ParticleDeformation[id], def_[id]);
 	}
+
+	for (auto& v : vol_) vol.append(v);
+	for (auto& v : poro_) poro.append(v);
+	if (deformation) for (auto& v : def_) def.append(v);
 	boost::python::dict ret;
 	ret["vol"]  = vol;
 	ret["poro"] = poro;
@@ -440,20 +382,19 @@ boost::python::list TesselationWrapper::getAlphaCaps(Real alpha, Real shrinkedAl
 {
 	vector<AlphaCap> caps;
 	Tes->setExtendedAlphaCaps(caps, alpha, shrinkedAlpha, fixedAlpha);
+	bounded=true;
 	boost::python::list ret;
 	for (auto f = caps.begin(); f != caps.end(); f++)
 		ret.append(boost::python::make_tuple(f->id, makeVector3r(f->normal), makeVector3r(f->centroid)));
-	//    cerr<<"number of caps="<<caps.size()<<endl;
 	return ret;
 }
 
 void TesselationWrapper::applyAlphaForces(Matrix3r stress, Real alpha, Real shrinkedAlpha, bool fixedAlpha, bool reset)
 {
-	// Scene* scene = Omega::instance().getScene().get();
 	if ((Tes->Triangulation().number_of_vertices() == 0) or reset) insertSceneSpheres(true);
-	// 	build_triangulation_with_ids(scene->bodies, *this, true); //triangulation needed
 	vector<AlphaCap> caps;
 	Tes->setExtendedAlphaCaps(caps, alpha, shrinkedAlpha, fixedAlpha);
+	bounded = true;
 	for (const auto& b : *scene->bodies)
 		scene->forces.setPermForce(b->id, Vector3r::Zero());
 	for (auto f = caps.begin(); f != caps.end(); f++) {
@@ -464,10 +405,10 @@ void TesselationWrapper::applyAlphaForces(Matrix3r stress, Real alpha, Real shri
 
 void TesselationWrapper::applyAlphaVel(Matrix3r velGrad, Real alpha, Real shrinkedAlpha, bool fixedAlpha)
 {
-	// Scene* scene = Omega::instance().getScene().get();
 	build_triangulation_with_ids(scene->bodies, *this, true); //triangulation needed
 	vector<AlphaCap> caps;
 	Tes->setExtendedAlphaCaps(caps, alpha, shrinkedAlpha, fixedAlpha);
+	bounded=true;
 	for (const auto& b : *scene->bodies)
 		b->state->blockedDOFs = State::DOF_NONE;
 	const auto aabb     = Shop::aabbExtrema();
@@ -482,10 +423,10 @@ void TesselationWrapper::applyAlphaVel(Matrix3r velGrad, Real alpha, Real shrink
 
 Matrix3r TesselationWrapper::calcAlphaStress(Real alpha, Real shrinkedAlpha, bool fixedAlpha)
 {
-	// Scene* scene = Omega::instance().getScene().get();
 	build_triangulation_with_ids(scene->bodies, *this, true); //triangulation needed
 	vector<AlphaCap> caps;
 	Tes->setExtendedAlphaCaps(caps, alpha, shrinkedAlpha, fixedAlpha);
+	bounded=true;
 	Matrix3r cauchyLWS(Matrix3r::Zero());
 	scene->forces.sync(); // needed to make resultants predictable
 	alphaCapsVol = 0.;
@@ -504,6 +445,7 @@ boost::python::list TesselationWrapper::getAlphaGraph(Real alpha, Real shrinkedA
 {
 	if (Tes->Triangulation().number_of_vertices() == 0) insertSceneSpheres(true);
 	segments = Tes->getExtendedAlphaGraph(alpha, shrinkedAlpha, fixedAlpha);
+	bounded = true;
 	boost::python::list ret;
 	for (auto f = segments.begin(); f != segments.end(); f++)
 		ret.append(*f);
@@ -546,7 +488,6 @@ void GlExtra_AlphaGraph::render()
 		rots.clear();
 		lengths.clear();
 	}
-	// 	const vector<Vector3r>& segments_ = segments;
 	const vector<Vector3r>& segments_ = tesselationWrapper->segments;
 	unsigned                maxI      = segments_.size() - 1;
 	glLineWidth(lineWidth);
@@ -578,8 +519,6 @@ void GlExtra_AlphaGraph::render()
 			gluQuadric = gluNewQuadric();
 			if (!gluQuadric) throw runtime_error("Gl1_NormPhys::go unable to allocate new GLUquadric object (out of memory?).");
 		}
-		// 		glCylinderList = glGenLists(1);
-		// 		glNewList(glCylinderList, GL_COMPILE); // create the list here, call it after the "if{}".
 		while (i < maxI) {
 			const Vector3r& p1 = segments_[i];
 			const Vector3r& p2 = segments_[i + 1];
@@ -600,7 +539,6 @@ void GlExtra_AlphaGraph::render()
 			++jj;
 		}
 	}
-	// 	glCallList(glCylinderList);
 }
 #endif /*OPENGL*/
 
