@@ -79,7 +79,7 @@ py::tuple interactionAnglesHistogram(int axis, int mask, size_t bins, py::tuple
 	shared_ptr<Scene> rb = Omega::instance().getScene();
 	for (const auto& i : *rb->interactions) {
 		if (!i->isReal()) continue;
-		const shared_ptr<Body>&b1 = Body::byId(i->getId1(), rb), b2 = Body::byId(i->getId2(), rb);
+		const auto b1 = Body::byId(i->getId1(), rb), b2 = Body::byId(i->getId2(), rb);
 		if (!b1->maskOk(mask) || !b2->maskOk(mask)) continue;
 		if (useBB && !Shop::isInBB(b1->state->pos, bbMin, bbMax) && !Shop::isInBB(b2->state->pos, bbMin, bbMax)) continue;
 		if (sphSph && (!dynamic_cast<Sphere*>(b1->shape.get()) || !dynamic_cast<Sphere*>(b2->shape.get()))) continue;
@@ -117,7 +117,7 @@ py::tuple bodyNumInteractionsHistogram(py::tuple aabb)
 	for (const auto& i : *rb->interactions) {
 		if (!i->isReal()) continue;
 		const Body::id_t       id1 = i->getId1(), id2 = i->getId2();
-		const shared_ptr<Body>&b1 = Body::byId(id1, rb), b2 = Body::byId(id2, rb);
+		const auto b1 = Body::byId(id1, rb), b2 = Body::byId(id2, rb);
 		if ((useBB && Shop::isInBB(b1->state->pos, bbMin, bbMax)) || !useBB) {
 			if (b1->isClumpMember()) bodyNumIntr[b1->clumpId] += 1; //count bodyNumIntr for the clump, not for the member
 			else
@@ -135,7 +135,7 @@ py::tuple bodyNumInteractionsHistogram(py::tuple aabb)
 	vector<int> bins;
 	bins.resize(maxIntr + 1, 0);
 	for (size_t id = 0; id < bodyNumIntr.size(); id++) {
-		const shared_ptr<Body>& b = Body::byId(id, rb);
+		const auto b = Body::byId(id, rb);
 		if (b) {
 			if (bodyNumIntr[id] > 0) bins[bodyNumIntr[id]] += 1;
 			// 0 is handled specially: add body to the 0 bin only if it is inside the bb requested (if applicable)
@@ -665,8 +665,7 @@ try {
 	        (py::args("findMaxId") = false),
 	        "Compute overall kinetic energy of the simulation as\n\n.. math:: "
 	        "\\sum\\frac{1}{2}\\left(m_i\\vec{v}_i^2+\\vec{\\omega}(\\mat{I}\\vec{\\omega}^T)\\right).\n\nFor :yref:`aspherical<Body.aspherical>` bodies, "
-	        "the inertia tensor $\\mat{I}$ is transformed to global frame, before multiplied by $\\vec{\\omega}$, therefore the value should be "
-	        "accurate.\n");
+	        "necessary frame transformations are applied to the inertia tensor $\\mat{I}$ as stored in :yref:`state.inertia<State.inertia>`.\n");
 	py::def("sumForces",
 	        sumForces,
 	        (py::arg("ids"), py::arg("direction")),
@@ -852,8 +851,8 @@ try {
 	py::def("calm",
 	        Shop__calm,
 	        (py::arg("mask") = -1),
-	        "Set translational and rotational velocities of bodies to zero. Applied to all bodies by default. To calm only some bodies, use mask "
-	        "parameter, it will calm only bodies with groupMask compatible to given value");
+	        "Set translational and rotational velocities of bodies to zero. Applied to all :yref:`dynamic<Body.dynamic>` bodies by default. To calm only "
+	        "some of them, use mask parameter, it will calm only dynamic bodies with groupMask compatible to given value");
 	py::def("setNewVerticesOfFacet",
 	        setNewVerticesOfFacet,
 	        (py::arg("b"), py::arg("v1"), py::arg("v2"), py::arg("v3")),
