@@ -14,13 +14,6 @@ For examples, see
 * :ysrc:`examples/gts-horse/gts-horse.py`
 * :ysrc:`examples/WireMatPM/wirepackings.py`
 """
-from __future__ import print_function
-
-from future import standard_library
-standard_library.install_aliases()
-from builtins import map
-
-from builtins import range
 import itertools, warnings
 from numpy import arange
 from math import sqrt
