@@ -7,13 +7,6 @@
 
 Devs: please DO NOT ADD more functions here, it is getting too crowded!
 """
-from __future__ import print_function
-
-from future import standard_library
-standard_library.install_aliases()
-
-from builtins import range
-from builtins import object
 import math, random, doctest, numpy
 from yade import *
 import yade.math
@@ -369,10 +362,12 @@ def levelSetBody(
         grid=None,
         distField=[],
         smearCoeff=1.5,
-        nSurfNodes=27,
+        nSurfNodes=102,
         nodesPath=2,
         nodesTol=50,
         orientation=Quaternion(1, 0, 0, 0),
+        hasAABE=False,
+        axesAABE=Vector3.Zero,
         dynamic=True,
         material=-1
 ):
@@ -387,11 +382,13 @@ def levelSetBody(
 	:param Real spacing: spatial increment of the :yref:`level set grid<LevelSet.lsGrid>`, if you picked a pre-defined *shape* or a *clump*
 	:param list distField: the :yref:`discrete distance field<LevelSet.distField>` on *grid* (if given) as a list (of list of list; use .tolist() if working initially with 3D numpy arrays), where distField[i][j][k] is the distance value at grid.gridPoint(i,j,k)
 	:param RegularGrid grid: the :yref:`grid carrying the distance field<LevelSet.lsGrid>`, when the latter is directly assigned through *distField*
-        :param Real smearCoeff: passed to :yref:`LevelSet.smearCoeff`
+	:param Real smearCoeff: passed to :yref:`LevelSet.smearCoeff`
 	:param int nSurfNodes: number of boundary nodes, passed to :yref:`LevelSet.nSurfNodes`
 	:param int nodesPath: path for the boundary nodes, passed to :yref:`LevelSet.nodesPath`
 	:param Real nodesTol: tolerance while ray tracing boundary nodes, passed to :yref:`LevelSet.nodesTol`
 	:param Quaternion orientation: the initial orientation of the body
+	:param bool hasAABE: flag indicating if the axis-aligned bounding ellipsoid (AABE) was set, passed to :yref:`LevelSet.hasAABE`
+	:param Vector3 axesAABE: principal half-axes of the axis aligned bounding ellipsoid (AABE) when *hasAABE*, passed to :yref:`LevelSet.axesAABE`
 	:param bool dynamic: passed to :yref:`Body.dynamic`
 	:param Material material: passed to :yref:`Body.material`
 	:return: a corresponding body instance"""
@@ -421,7 +418,7 @@ def levelSetBody(
 			extents = Vector3(extents[0], extents[1], extents[2])
 		b.shape = lsSimpleShape(3, AlignedBox3(-extents, extents), epsilons=epsilons, step=spacing, smearCoeff=smearCoeff)
 	elif len(distField):
-		b.shape = LevelSet(lsGrid=grid, distField=distField, smearCoeff=smearCoeff)
+		b.shape = LevelSet(lsGrid=grid, distField=distField, smearCoeff=smearCoeff) # NB: we could pass twoD = sthg here, function of distField size
 	if clump != None:
 		if not isinstance(clump, Clump):
 			raise ValueError("Please give a Clump instance as a clump attribute, instead of ", clump)
@@ -449,6 +446,8 @@ def levelSetBody(
 	else:
 		b.aspherical = True
 	b.state.ori = b.state.refOri = orientation
+	b.shape.hasAABE = hasAABE
+	b.shape.axesAABE = axesAABE
 	return b
 
 
