@@ -26,8 +26,6 @@
 #include <pkg/dem/STLImporter.hpp>
 #include <boost/algorithm/string.hpp>
 #include <boost/archive/codecvt_null.hpp>
-#include <boost/bind.hpp>
-#include <boost/lambda/bind.hpp>
 #include <boost/math/special_functions/nonfinite_num_facets.hpp>
 #include <boost/python/raw_function.hpp>
 #include <boost/random/linear_congruential.hpp>
@@ -185,18 +183,12 @@ public:
 	{ //FIXME
 		const shared_ptr<Clump> clump(YADE_PTR_CAST<Clump>(clumpBody->shape));
 		if (clump->members.size() == 1) {
-			Clump::del(clumpBody, memberBody); //phD was not commented out
-			for (unsigned i = 0; i < clump->ids.size(); i++) {
-				if (clump->ids[i] == memberBody->getId()) { clump->ids.erase(clump->ids.begin() + i); }
-			}
+			Clump::del(clumpBody, memberBody);
 			proxee->erase(memberBody->getId(), false);
 			proxee->erase(clumpBody->getId(), false);
 
 		} else {
-			Clump::del(clumpBody, memberBody); //pHD was not commented out
-			for (unsigned i = 0; i < clump->ids.size(); i++) {
-				if (clump->ids[i] == memberBody->getId()) { clump->ids.erase(clump->ids.begin() + i); }
-			}
+			Clump::del(clumpBody, memberBody);
 			Clump::updatePropertiesNonSpherical(clumpBody, /*intersecting*/ false);
 			proxee->erase(memberBody->getId(), false);
 		}
@@ -204,24 +196,17 @@ public:
 	void deleteClumpBody(shared_ptr<Body> clumpBody)
 	{ //FIXME
 		const shared_ptr<Clump> clump(YADE_PTR_CAST<Clump>(clumpBody->shape));
-
-		//if (clump->members.size()==0 ){
-		//	proxee->erase(clumpBody->getId());
-		//}else{
 		Scene* scene(Omega::instance().getScene().get());
-		int    totalNumber = clump->ids.size();
+		int    totalNumber = clump->members.size();
 		int    count       = 0;
 		while (count < totalNumber) {
-			//for (int i=0; i<clump->ids.size(); i++){
-			shared_ptr<Body> memberBody(YADE_PTR_CAST<Body>(Body::byId(clump->ids[/*i */ 0], scene)));
+			//each time we erase the first one (begin()), the next one becomes first
+			shared_ptr<Body> memberBody(YADE_PTR_CAST<Body>(Body::byId(clump->members.begin()->first, scene)));
 			deleteClumpMember(clumpBody, memberBody);
-			//clump->ids.erase(clump->ids.begin()+i);
-			//proxee->erase(memberBody->getId());
 			count++;
 		}
 
 		proxee->erase(clumpBody->getId(), true);
-		//}
 	}
 	void addToClump(vector<Body::id_t> bids, Body::id_t cid, unsigned int discretization)
 	{
@@ -1360,7 +1345,7 @@ try {
 	        .value("triggerPostLoad", yade::Attr::triggerPostLoad)
 	        .value("noResize", yade::Attr::noResize);
 
-	py::class_<pyOmega>("Omega")
+	py::class_<pyOmega>("Omega","The whole YADE world made of one or, possibly, several :yref:`scenes<Scene>` serving as independent simulations. The Omega instance is accessed as `O`, e.g., `O.bodies`")
 	        .add_property("iter", &pyOmega::iter, "Get current step number")
 	        .add_property(
 	                "subStep",
@@ -1489,7 +1474,7 @@ try {
 	                "e.g. ``O.interactions[23,65]``\n#. iteraction over the whole container::\n\n\tfor i in O.interactions: print i.id1,i.id2\n\n.. "
 	                "note::\n\tIteration silently skips interactions that are not :yref:`real<Interaction.isReal>`.")
 	        .add_property("materials", &pyOmega::materials_get, "Shared materials; they can be accessed by id or by label")
-	        .add_property("forces", &pyOmega::forces_get, ":yref:`ForceContainer` (forces, torques, displacements) in the current simulation.")
+	        .add_property("forces", &pyOmega::forces_get, ":yref:`ForceContainer` (forces, torques) in the current simulation.")
 	        .add_property(
 	                "energy",
 	                &pyOmega::energy_get,
@@ -1516,7 +1501,7 @@ try {
 	                "Counter for number of syncs in ForceContainer, for profiling purposes.")
 	        .add_property("numThreads", &pyOmega::numThreads_get /* ,&pyOmega::numThreads_set*/, "Get maximum number of threads openMP can use.")
 	        .add_property("cell", &pyOmega::cell_get, "Periodic :yref:`Cell` of the current scene (None if the scene is aperiodic).")
-	        .add_property("periodic", &pyOmega::periodic_get, &pyOmega::periodic_set, "Get/set whether the scene is periodic or not (True/False).")
+	        .add_property("periodic", &pyOmega::periodic_get, &pyOmega::periodic_set, "Get/set whether the current :yref:`scene is periodic<Scene.isPeriodic>` or not (True/False).")
 	        .def("exitNoBacktrace",
 	             &pyOmega::exitNoBacktrace,
 	             (py::arg("status") = 0),
@@ -1562,10 +1547,10 @@ try {
 	             &pyBodyContainer::clump,
 	             (py::arg("discretization") = 0),
 	             "Clump given bodies together (creating a rigid aggregate); returns ``clumpId``. A precise definition of clump masses and inertia when "
-	             "clump members overlap requires *discretization*>0 and is achieved in this case by integration/summation over mass points using a regular "
-	             "grid of cells (grid cells length is defined as $L_{min}/discretization$, where $L_{min}$ is the minimum length of an Axis-Aligned "
-	             "Bounding Box. If *discretization*<=0 sum of inertias from members is simply used, which is faster but accurate only for non-overlapping "
-	             "members).")
+	             "clump members overlap requires spherical members together with *discretization*>0 and is achieved in this case by integration/summation "
+	             "over mass points using a regular grid of cells (grid cells length is defined as $L_{min}/discretization$, where $L_{min}$ is the minimum "
+	             "length of an Axis-Aligned Bounding Box. If *discretization*<=0 sum of inertias from members is simply used, which is faster but accurate "
+	             "only for non-overlapping members).")
 	        .def("updateClumpProperties",
 	             &pyBodyContainer::updateClumpProperties,
 	             (py::arg("excludeList") = py::list(), py::arg("discretization") = 5),
