@@ -1,13 +1,14 @@
 # encoding: utf-8
 # 2011 © Bruno Chareyre <bruno.chareyre@grenoble-inp.fr>
-from __future__ import print_function
-from past.builtins import execfile
+
 import yade
+from yade.yexecfile import execfile
 import math
 import os
 import sys
 import time
 import datetime
+import traceback
 
 
 class YadeCheckError(Exception):
@@ -33,7 +34,7 @@ skipScripts = ['checkList.py']
 # use this if you want to test only one script, it takes precedence over skipScripts.
 onlyOneScript = []
 
-mpiScripts = ['checkMPI.py', 'checkMPISilo.py', 'checkMPI4PYcomm.py']
+mpiScripts = ['checkMPI.py', 'checkMPISilo.py', 'checkMPI4PYcomm.py', 'checkMPYcomm.py']
 # singleCore = singleCore + mpiScripts # ignore hybrid MPIxOMP
 
 
@@ -43,6 +44,8 @@ def acceptOMPIVersion():  # filter out specific distros for MPI checks
 		return False
 	if yade.libVersions.getAllVersionsCpp()['mpi'][0][0] == 2:
 		return False
+	if yade.libVersions.getAllVersionsCpp()['mpi'][1] == 'ompi:4.1.5':
+		return False # Open MPI 4.1.5 has a bug https://gitlab.com/yade-dev/trunk/-/issues/309  https://github.com/open-mpi/ompi/issues/11749
 	return True
 
 
@@ -82,6 +85,7 @@ for script in scriptsToRun:
 			print("___________________________________")
 		except Exception as e:
 			failedScripts.append(script)
+			traceback.print_exc()
 			print('\033[91m', script, " failure, caught exception ", e.__class__.__name__, ": ", e, '\033[0m')
 		O.reset()
 	elif (not mustCheck(script)[0]):
